@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="it">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
 <context>
     <name>QObject</name>
     <message>
@@ -482,12 +480,12 @@
     <message>
         <location filename="../defaultlook.ui" line="982"/>
         <source>Thunar windows always open in split view</source>
-        <translation type="unfinished"></translation>
+        <translation>Le finestre di Thunar si aprono sempre in vista separata</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="1061"/>
         <source>Thunar split view opens horizontal</source>
-        <translation type="unfinished"></translation>
+        <translation>La vista separata di Thunar si apre in orizzontale</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="1071"/>
@@ -1099,4 +1097,4 @@
         <translation>Impostazioni del Compositore Xfwm </translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
